Orthogonalization
==============================

.. contents::
    :depth: 2
    :local:


.. currentmodule:: cr.nimble


Householder Reflections
-----------------------------

.. autosummary::
    :toctree: _autosummary

    householder_vec
    householder_matrix
    householder_premultiply
    householder_postmultiply
    householder_ffm_jth_v_beta
    householder_ffm_premultiply
    householder_ffm_backward_accum
    householder_ffm_to_wy
    householder_qr_packed
    householder_split_qf_r
    householder_qr
